@@ -1,6 +1,5 @@
 from six import string_types, binary_type
-from vjson import json_helper
-
+from vxbase.vjson import json_helper
 import locale
 
 try:
